Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Enum UFrameWireError

pub enum UFrameWireError {
    InvalidFrame(String),
    UnsupportedPayloadEncoding(String),
    SerializationError(String),
}
Error type used by whole-frame wire formats.

Variants



InvalidFrame(String)

The encoded bytes do not contain a valid frame or violate native frame invariants.



UnsupportedPayloadEncoding(String)

The selected wire format cannot faithfully represent the frame payload encoding.



SerializationError(String)

The wire format encoder or decoder failed while converting bytes.

Implementations

Source

impl UFrameWireError

pub fn invalid_frame(message: impl Into<String>) -> Self

pub fn unsupported_payload_encoding(message: impl Into<String>) -> Self

pub fn serialization_error(message: impl Into<String>) -> Self