pub enum UFrameWireError {
InvalidFrame(String),
UnsupportedPayloadEncoding(String),
SerializationError(String),
}Expand description
Error type used by whole-frame wire formats.
Variants
InvalidFrame(String)
The encoded bytes do not contain a valid frame or violate native frame invariants.
UnsupportedPayloadEncoding(String)
The selected wire format cannot faithfully represent the frame payload encoding.
SerializationError(String)
The wire format encoder or decoder failed while converting bytes.
Implementations
Sourceimpl UFrameWireError
impl UFrameWireError
Sourcepub fn invalid_frame(message: impl Into<String>) -> Self
pub fn invalid_frame(message: impl Into<String>) -> Self
Creates an UFrameWireError::InvalidFrame value.
Sourcepub fn unsupported_payload_encoding(message: impl Into<String>) -> Self
pub fn unsupported_payload_encoding(message: impl Into<String>) -> Self
Creates an UFrameWireError::UnsupportedPayloadEncoding value.
Sourcepub fn serialization_error(message: impl Into<String>) -> Self
pub fn serialization_error(message: impl Into<String>) -> Self
Creates an UFrameWireError::SerializationError value.